import React, { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import axiosInstance from '../../api/axiosConfig'; 
import './LoginPage.css';

const LoginPage = () => {
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const [error, setError] = useState('');
  const navigate = useNavigate();

  const handleLogin = async (e) => {
    e.preventDefault();
    setError('');
  
    try {
      const response = await axiosInstance.get('http://localhost:5000/users');
  
      const user = response.data.find(user => user.email === email && user.password === password);
  
      if (user) {
        if (user.role === 'admin') {
          navigate('/admin');
        } else if (user.role === 'employee') {
          navigate('/employee');
        } else {
          setError('Invalid credentials');
        }
      } else {
        setError('Invalid credentials');
      }
    } catch (err) {
      if (err.response) {
        setError(`Login failed: ${err.response.data.message}`);
      } else if (err.request) {
        setError('Login failed. No response from server.');
      } else {
        setError('Login failed. Please try again.');
      }
    }
  };
  
  return (
    <div className="flex flex-row min-h-screen justify-center items-center">
      <div className="login-page flex items-center justify-center min-h-screen w-full md:w-1/2 lg:w-1/3 p-4">
        <div className="w-full">
          <h2>Welcome Back</h2>
          <p>Be among the first to experience 3D magic! Register for private alpha.</p>
          {error && <p className="error-message">{error}</p>}
          <form onSubmit={handleLogin} className="space-y-4">
            <label htmlFor="email" className="block"></label>
            <input
              type="email"
              id="email"
              name="email"
              value={email}
              onChange={(e) => setEmail(e.target.value)}
              placeholder="john123@domain.com"
              required
              className="input-field"
            />
            <label htmlFor="password" className="block"></label>
            <input
              type="password"
              id="password"
              name="password"
              value={password}
              onChange={(e) => setPassword(e.target.value)}
              placeholder="Enter your password"
              required
              className="input-field"
            />
            <div className="forgot-password-container">
              <a href="#">Forgot password?</a>
            </div>
            <button type="submit" className="login-button">
              Login
            </button>
          </form>
        </div>
      </div>
    </div>
  );
};

export default LoginPage;
