import React, { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import Sidebar from '../sidebar/Sidebar';

const CustomerList = () => {
  const [customers, setCustomers] = useState([]);
  const navigate = useNavigate();

  useEffect(() => {
    // Fetch the customers data from the JSON file
    fetch('/customers.json')
      .then((response) => response.json())
      .then((data) => setCustomers(data))
      .catch((error) => console.error('Error fetching customers:', error));
  }, []);

  const handleAddCustomer = () => {
    navigate('/add-customer');
  };

  return (
    <div className="flex flex-row min-h-screen">
      <Sidebar />
      <div className="w-full flex flex-col bg-#090909B text-white">
        <div className="bg-[#090909B] text-gray-300 p-6 rounded-lg">
          <div className="flex justify-between items-center mb-4">
            <h1 className="text-xl font-semibold text-orange-500">Customers List</h1>
            <button
              className="bg-orange-500 text-black px-4 py-2 rounded-md text-sm"
              onClick={handleAddCustomer}
            >
              Add New Customer
            </button>
          </div>
          <div className="flex items-center mb-4">
            <svg className="w-5 h-5 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M3 4a1 1 0 011-1h16a1 1 0 011 1v2.586a1 1 0 01-.293.707l-6.414 6.414a1 1 0 00-.293.707V17l-4 4v-6.586a1 1 0 00-.293-.707L3.293 7.293A1 1 0 013 6.586V4z" />
            </svg>
            <span className="text-sm">Filter</span>
          </div>
          <p className="text-sm mb-4">Total Customers ({customers.length})</p>
          <table className="w-full">
            <thead>
              <tr className="text-left text-xs uppercase">
                <th className="py-2">#</th>
                <th className="py-2">Customer ID</th>
                <th className="py-2">Customer Name</th>
              </tr>
            </thead>
            <tbody>
              {customers.map((customer, index) => (
                <tr key={customer.id} className="border-t border-gray-700">
                  <td className="py-2">{index + 1}</td>
                  <td className="py-2">{customer.id}</td>
                  <td className="py-2">{customer.name}</td>
                </tr>
              ))}
            </tbody>
          </table>
        </div>
      </div>
    </div>
  );
};

export default CustomerList;
