import React from 'react';
import { Button, Input, Form } from 'antd';
import { Link } from 'react-router-dom';
import axios from 'axios';
import Sidebar from '../sidebar/Sidebar';

const CustomerMeasurements = () => {
  const onFinish = async (values) => {
    const token = localStorage.getItem('token'); // Assuming the token is stored in localStorage

    try {
      const response = await axios.post('http://localhost:8080/measurements', values, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
      });

      console.log(response.data);
    } catch (error) {
      console.error('Error saving measurements:', error);
    }
  };

  return (
    <div className="flex flex-row">
      <Sidebar />
      <div className="w-full flex flex-col min-h-screen text-white">
        <div className="min-h-screen text-gray-300 p-6">
          <div className="flex justify-between items-center mb-6">
            <h1 className="text-2xl font-semibold text-orange-500">Customer Measurements</h1>
            <Link to="/" className="text-orange-500">skip for now</Link>
          </div>
          <Form onFinish={onFinish} className="space-y-4">
            <h2 className="text-lg font-semibold text-gray-400">Upper Body Measurements</h2>
            <Form.Item name="neck" label={<span className="text-white">Neck Circumference (in inch)</span>}>
              <Input className="block text-sm font-medium text-black-400" />
            </Form.Item>
            <Form.Item name="chest" label={<span className="text-white">Chest Circumference (in inch)</span>}>
              <Input className="block text-sm font-medium text-black-400" />
            </Form.Item>
            <Form.Item name="waist" label={<span className="text-white">Waist Circumference (in inch)</span>}>
              <Input className="block text-sm font-medium text-black-400" />
            </Form.Item>
            <Form.Item name="shoulder" label={<span className="text-white">Shoulder Width (in inch)</span>}>
              <Input className="block text-sm font-medium text-black-400" />
            </Form.Item>
            <Form.Item name="arm" label={<span className="text-white">Arm Length (in inch)</span>}>
              <Input className="block text-sm font-medium text-black-400" />
            </Form.Item>
            <Form.Item name="sleeve" label={<span className="text-white">Sleeve Length (in inch)</span>}>
              <Input className="block text-sm font-medium text-black-400" />
            </Form.Item>

            <h2 className="text-lg font-semibold text-gray-400">Lower Body Measurements</h2>
            <Form.Item name="hip" label={<span className="text-white">Hip Circumference (in inch)</span>}>
              <Input className="block text-sm font-medium text-black-400" />
            </Form.Item>
            <Form.Item name="inseam" label={<span className="text-white">Inseam (in inch)</span>}>
              <Input className="block text-sm font-medium text-black-400" />
            </Form.Item>
            <Form.Item name="outseam" label={<span className="text-white">Out Seam (in inch)</span>}>
              <Input className="block text-sm font-medium text-black-400" />
            </Form.Item>
            <Form.Item name="thigh" label={<span className="text-white">Thigh Circumference (in inch)</span>}>
              <Input className="block text-sm font-medium text-black-400" />
            </Form.Item>
            <Form.Item name="ankle" label={<span className="text-white">Ankle Circumference (in inch)</span>}>
              <Input className="block text-sm font-medium text-black-400" />
            </Form.Item>
            <Form.Item>
              <Button type="primary" htmlType="submit" className="w-full py-4 bg-orange-500 text-black rounded-md font-semibold mb-4 hover:bg-orange-400">
                Save Measurements
              </Button>
            </Form.Item>
          </Form>
        </div>
      </div>
    </div>
  );
};

export default CustomerMeasurements;
